agde::event

Enum RewindError

source
pub enum RewindError {
    Apply(ApplyError, Vec<u8>),
    ResourceDestroyed(Vec<u8>),
}
An error when rewinding.

Variants



Apply(ApplyError, Vec<u8>)

An error occurred when applying a diff.

The rewound resource is also returned, if you want to use it. The diffs which erred aren’t applied.



ResourceDestroyed(Vec<u8>)

The resource has been destroyed since last commit. Throw away your changes.

The inner byte array is the data supposed to be rewound.

Implementations

source

impl RewindError

source

pub fn into_data(self) -> Vec<u8>

Returns the recovered data.