agde::event

Enum UnwindError

source
pub enum UnwindError {
    ResourceDestroyed(Vec<u8>),
    Apply(ApplyError, Vec<u8>),
}
Error during Unwinder operations.

Variants



ResourceDestroyed(Vec<u8>)

The resource has previously been destroyed.

The returned byte array contains the unchanged data passed to the function.



Apply(ApplyError, Vec<u8>)

An error during an application of a section.

The rewound resource is also returned, if you want to use it. The diffs which erred aren’t applied.

Implementations

source

impl UnwindError

source

pub fn into_data(self) -> Vec<u8>

Get the data of this error.